Person - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Person

A `betty.model.ancestry.Person` describes an individual human being.

## Fields

People inherit from:

- Privacy

`children` (an iterable of `Person`)

  The person’s children.

`files` (iterable of File)

  The files attached to this person.

`citations` (iterable of Citation)

  The citations for this person.

`id` (`str`)

  The person’s own entity ID.

`links` (iterable of Link)

  The external links for this person.

`names` (iterable of PersonName)

  The person’s names.

`parents` (an iterable of `Person`)

  The person’s parents.

`presences` (iterable of Presence)

  The person’s presences at events.

`siblings` (an iterable of `Person`)

  The person’s siblings.